#ifdef __cplusplus
extern "C"
{
#endif

/*
**
** AJAX master include file
**
*/

#ifndef ajax_h
#define ajax_h

#include <stdio.h>

#include "ajarch.h"

#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "ajassert.h"
#include "ajdefine.h"
#include "ajstr.h"
#include "ajtime.h"
#include "ajfile.h"
#include "ajfiledata.h"
#include "ajfileio.h"
#include "ajlist.h"

#include "ajtable.h"
#include "ajnexus.h"
#include "ajfeat.h"
#include "ajseq.h"
#include "ajseqdata.h"
#include "ajseqtype.h"
#include "ajarr.h"
#include "ajseqread.h"
#include "ajseqwrite.h"
#include "ajindex.h"
#include "ajseqabi.h"
#include "ajreport.h"
#include "ajfmt.h"
#include "ajmatrices.h"
#include "ajalign.h"

#include "ajtranslate.h"
#include "ajrange.h"
#include "ajcod.h"
#include "ajmath.h"
#include "ajmem.h"
#include "ajutil.h"
#include "ajtree.h"
#include "ajexcept.h"
#include "ajnam.h"
#include "ajmess.h"

#include "ajphylo.h"
#include "ajreg.h"
#include "ajsys.h"
#include "ajbase.h"
#include "ajdan.h"
#include "ajsort.h"
#include "ajpdb.h"
#include "ajdomain.h"
#include "ajpdbio.h"
#include "ajdmx.h"
#include "ajpat.h"
#include "ajcall.h"
#include "ajjava.h"
#include "ajvector.h"
#include "ajdom.h"
#include "ajsql.h"
#include "ajobo.h"
#include "ajtax.h"
#include "ajresource.h"
    
#endif

#ifdef __cplusplus
}
#endif
